#####################
Source and Sink classes
#####################

.. |br| raw:: html

   <br />

Sources and sink transfer commodities into and out of the energy system.

**Source class description:**

.. automodule:: sourceSink
.. autoclass:: Source
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Source
   :parts: 1

|

**Sink class description:**

.. autoclass:: Sink
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Sink
   :parts: 1

|

**ComponentModel class description:**

.. autoclass:: SourceSinkModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: SourceSinkModel
   :parts: 1